%global with_tests 0
%global desc These provide several pieces of "middleware" (or filters) that can be nested\
to build web applications.  Each piece of middleware uses the WSGI (PEP 333)\
interface, and should be compatible with other middleware based on those\
interfaces.
%global sum Tools for using a Web Server Gateway Interface stack

Name:           python-paste
Version:        3.0.8
Release:        1.0.1%{?dist}.1
BuildArch:      noarch

# Most of the code is MIT
# paste/exceptions/collector.py is ZPLv2.0
# paste/evalexception/media/MochiKit.packed.js AFL (2.1) or MIT
# paste/lint.py MIT or Apache v2
# PySourceColor.py, Python
License:        MIT and ZPLv2.0 and Python and (AFL or MIT) and (MIT or ASL 2.0)
Summary:        %sum
URL:            https://github.com/cdent/paste
Source0:        https://files.pythonhosted.org/packages/source/P/Paste/Paste-%{version}.tar.gz


BuildRequires:  python3-devel
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-runner
BuildRequires:  python3-setuptools
BuildRequires:  python3-six >= 1.4.0

%if 0%{?with_tests}
BuildRequires:  python3-nose
BuildRequires:  python3-pyOpenSSL
BuildRequires:  python3-tempita
%endif # with_tests


%description
%desc


%package -n python3-paste
Summary:        Tools for using a Web Server Gateway Interface stack

%{?python_provide:%python_provide python3-paste}

Requires: python3-pyOpenSSL
Requires: python3-setuptools
Requires: python3-six
Requires: python3-tempita


%description -n python3-paste
%{desc}


%prep
%autosetup -n Paste-%{version} -p1

# Paste-2.0.3 seems to have a few .py.orig files that don't appear in upstream scm. Let's drop them.
find . -name "*.orig" -delete

# Strip #! lines that make these seem like scripts
%{__sed} -i -e '/^#!.*/,1 d' paste/util/scgiserver.py paste/debug/doctest_webapp.py

# clean docs directory
pushd docs
rm StyleGuide.txt
popd

rm -rf %{py3dir}
cp -a . %{py3dir}


%build
pushd %{py3dir}
%{__python3} setup.py build
popd


%install
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
popd


%if 0%{?with_tests}
%check
pushd %{py3dir}
export PYTHONPATH=$(pwd)
# We don't have access to the wider internet in the buildsystem
py.test-3 -k "not test_paste_website and not test_proxy_to_website and not test_modified"
popd
%endif # with_tests


%files -n python3-paste
%license docs/license.txt
%doc docs/*
%{python3_sitelib}/paste
%{python3_sitelib}/Paste-%{version}-py%{python3_version}.egg-info
%{python3_sitelib}/Paste-%{version}-py%{python3_version}-nspkg.pth


%changelog
* Mon Nov 09 2020 Lubos Kloucek <lubos.kloucek@oracle.com> - 3.0.8-1.0.1
- Drop python2-paste

* Thu Jun 20 2019 Troy Dawson <tdawson@redhat.com> - 3.0.8-1
- Turn off tests for initial EPEL8 build

* Thu Mar 28 2019 Randy Barlow <bowlofeggs@fedoraproject.org> - 3.0.8-1
- Update to 3.0.8 (#1684199).
- Update the URL to the new home on GitHub.

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 18 2018 Miro Hrončok <mhroncok@redhat.com> - 2.0.3-7
- Rebuilt for Python 3.7

* Fri Jun 08 2018 Miro Hrončok <mhroncok@redhat.com> - 2.0.3-6
- Fix build on Python 3.7 (#1583818)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 26 2018 Iryna Shcherbina <ishcherb@redhat.com> - 2.0.3-4
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)
